@@ -76,7 +76,7 @@ func init() {
 }
 
 func parseBuildLogRec(dir, tgt string) (map[string][]string, error) {
-	fd, err := os.Open(path.Join(dir, RedoDir, tgt+LogSuffix+DepSuffix))
+	fd, err := os.Open(path.Join(dir, RedoDir, tgt+LogRecSuffix))
 	if err != nil {
 		return nil, err
 	}
