@@ -116,7 +116,7 @@ func buildDependants(tgts []string) map[string]struct{} {
 	}
 	ok := true
 	for i := 0; i < len(seen); i++ {
-		ok = ok && isOkRun(<-errs)
+		ok = isOkRun(<-errs) && ok
 	}
 	Jobs.Wait()
 	close(errs)
@@ -163,7 +163,7 @@ RebuildDeps:
 		jobs++
 	}
 	for i := 0; i < jobs; i++ {
-		ok = ok && isOkRun(<-errs)
+		ok = isOkRun(<-errs) && ok
 	}
 	if !ok {
 		trace(CDebug, "dependants failed, skipping them")
@@ -217,7 +217,7 @@ func ifchange(tgts []string, forced, traced bool) (bool, error) {
 	}
 	ok := true
 	for ; jobs > 0; jobs-- {
-		ok = ok && isOkRun(<-errs)
+		ok = isOkRun(<-errs) && ok
 	}
 	return ok, nil
 }
