@@ -69,9 +69,18 @@ var (
 	jsTokens  map[byte]int
 	jsTokensM sync.Mutex
 
-	flagJobs = flag.Int("j", -1, fmt.Sprintf("number of parallel jobs (0=inf, <0=1) (%s)", EnvJobs))
+	flagJobs *int
 )
 
+func init() {
+	cmdName := CmdName()
+	if !(cmdName == CmdNameRedo || cmdName == CmdNameRedoIfchange) {
+		return
+	}
+	flagJobs = flag.Int("j", -1,
+		fmt.Sprintf("number of parallel jobs (0=inf, <0=1) (%s)", EnvJobs))
+}
+
 func jsStart(jobsEnv string) {
 	jobs := uint64(1)
 	var err error
