@@ -308,7 +308,14 @@ CmdSwitch:
 			log.Fatalln("no", EnvDepFd)
 		}
 		for _, tgt := range tgts {
-			err = ifcreate(fdDep, tgt)
+			tgtRel, err := filepath.Rel(
+				filepath.Join(Cwd, DirPrefix),
+				filepath.Join(Cwd, tgt),
+			)
+			if err != nil {
+				break
+			}
+			err = ifcreate(fdDep, tgtRel)
 			if err != nil {
 				break
 			}
