@@ -408,10 +408,11 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 		} else {
 			cmd.ExtraFiles = append(cmd.ExtraFiles, JSR)
 			cmd.ExtraFiles = append(cmd.ExtraFiles, JSW)
-			cmd.Env = append(cmd.Env, fmt.Sprintf(
-				"%s=%s %s%d,%d",
-				MakeFlagsName, MakeFlags, MakeJSArg, 3+fdNum+0, 3+fdNum+1,
-			))
+			makeFlags := fmt.Sprintf(
+				"%s %s%d,%d", MakeFlags, MakeJSArg, 3+fdNum+0, 3+fdNum+1,
+			)
+			makeFlags = strings.Trim(makeFlags, " ")
+			cmd.Env = append(cmd.Env, fmt.Sprintf("%s=%s", MakeFlagsName, makeFlags))
 			fdNum += 2
 			cmd.Env = append(cmd.Env, fmt.Sprintf("%s=%d", EnvJSToken, jsToken))
 		}
@@ -456,10 +457,14 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 				); err == nil {
 					fields := []recfile.Field{
 						{Name: "Build", Value: BuildUUID},
-						{Name: "PID", Value: strconv.Itoa(cmd.Process.Pid)},
 						{Name: "PPID", Value: strconv.Itoa(os.Getpid())},
 						{Name: "Cwd", Value: cwd},
 					}
+					if cmd.Process != nil {
+						fields = append(fields, recfile.Field{
+							Name: "PID", Value: strconv.Itoa(cmd.Process.Pid),
+						})
+					}
 					ts := new(tai64n.TAI64N)
 					ts.FromTime(started)
 					fields = append(fields,
@@ -474,7 +479,7 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 					})
 					fields = append(fields, recfile.Field{Name: "Cmd", Value: cmdName})
 					for _, arg := range args {
-						fields = append(fields, recfile.Field{Name: "Cmd", Value: arg})
+						fields = append(fields, recfile.Field{Name: "Arg", Value: arg})
 					}
 					for _, env := range cmd.Env {
 						fields = append(fields, recfile.Field{Name: "Env", Value: env})
